@@ -7,7 +7,8 @@ my @c = (
 );
 
 my $script = "chr\\chr.pl";
-open(SCRIPT,">$script") || die "Can't open file: $script\n";
+open(SCRIPT,">$script")      || die "Can't open file: $script\n";
+open(WANT,  ">$script.want") || die "Can't open file: $script.want\n";
 
 #----------------------------------------------------------------------------
 # chr
@@ -15,11 +16,13 @@ open(SCRIPT,">$script") || die "Can't open file: $script\n";
 
 for my $c (@c) {
     print SCRIPT "\$_ = $c; print chr, \"\\n\";\n";
+    print WANT pack('C',$c), "\n";
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "\$_ = ", $c1 * 256 + $c2, "; print chr, \"\\n\";\n";
+        print WANT pack('CC',$c1,$c2), "\n";
     }
 }
 
@@ -29,11 +32,13 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 
 for my $c (@c) {
     print SCRIPT "\$_ = $c; print chr \$_, \"\\n\";\n";
+    print WANT pack('C',$c), "\n";
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "\$_ = ", $c1 * 256 + $c2, "; print chr \$_, \"\\n\";\n";
+        print WANT pack('CC',$c1,$c2), "\n";
     }
 }
 
@@ -43,11 +48,13 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 
 for my $c (@c) {
     print SCRIPT "\$_ = $c; print chr(\$_), \"\\n\";\n";
+    print WANT pack('C',$c), "\n";
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "\$_ = ", $c1 * 256 + $c2, "; print chr(\$_), \"\\n\";\n";
+        print WANT pack('CC',$c1,$c2), "\n";
     }
 }
 
@@ -57,11 +64,13 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 
 for my $c (@c) {
     print SCRIPT "\$_ = $c; print chr \$_, 0x41, 0x42, 0x43, \"\\n\";\n";
+    print WANT pack('C',$c), 0x41, 0x42, 0x43, "\n";
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "\$_ = ", $c1 * 256 + $c2, "; print chr \$_, 0x41, 0x42, 0x43, \"\\n\";\n";
+        print WANT pack('CC',$c1,$c2), 0x41, 0x42, 0x43, "\n";
     }
 }
 
@@ -71,11 +80,13 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 
 for my $c (@c) {
     print SCRIPT "print chr $c, \"\\n\";\n";
+    print WANT pack('C',$c), "\n";
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "print chr ", $c1 * 256 + $c2, ", \"\\n\";\n";
+        print WANT pack('CC',$c1,$c2), "\n";
     }
 }
 
@@ -85,11 +96,13 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 
 for my $c (@c) {
     print SCRIPT "print chr($c), \"\\n\";\n";
+    print WANT pack('C',$c), "\n";
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "print chr(", $c1 * 256 + $c2, "), \"\\n\";\n";
+        print WANT pack('CC',$c1,$c2), "\n";
     }
 }
 
@@ -99,14 +112,17 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 
 for my $c (@c) {
     print SCRIPT "print chr $c, 0x41, 0x42, 0x43, \"\\n\";\n";
+    print WANT pack('C',$c), 0x41, 0x42, 0x43, "\n";
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "print chr ", $c1 * 256 + $c2, ", 0x41, 0x42, 0x43, \"\\n\";\n";
+        print WANT pack('CC',$c1,$c2), 0x41, 0x42, 0x43, "\n";
     }
 }
 
 close(SCRIPT);
+close(WANT);
 
 #----------------------------------------------------------------------------
