@@ -7,7 +7,8 @@ my @c = (
 );
 
 my $script = "ord\\ord.pl";
-open(SCRIPT,">$script") || die "Can't open file: $script\n";
+open(SCRIPT,">$script")      || die "Can't open file: $script\n";
+open(WANT,  ">$script.want") || die "Can't open file: $script.want\n";
 
 #----------------------------------------------------------------------------
 # ord
@@ -16,15 +17,18 @@ open(SCRIPT,">$script") || die "Can't open file: $script\n";
 for my $c (@c) {
     if ($c =~ /^['\\]$/) {
         print SCRIPT "\$_ = '\\", $c, "'; print ord, \"\\n\";\n";
+        print WANT ord($c), "\n";
     }
     else {
         print SCRIPT "\$_ = '", $c, "'; print ord, \"\\n\";\n";
+        print WANT ord($c), "\n";
     }
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "\$_ = '", chr($c1), chr($c2), "'; print ord, \"\\n\";\n";
+        print WANT $c1 * 256 + $c2, "\n";
     }
 }
 
@@ -35,15 +39,18 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 for my $c (@c) {
     if ($c =~ /^['\\]$/) {
         print SCRIPT "\$_ = '\\", $c, "'; print ord \$_, \"\\n\";\n";
+        print WANT ord($c), "\n";
     }
     else {
         print SCRIPT "\$_ = '", $c, "'; print ord \$_, \"\\n\";\n";
+        print WANT ord($c), "\n";
     }
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "\$_ = '", chr($c1), chr($c2), "'; print ord \$_, \"\\n\";\n";
+        print WANT $c1 * 256 + $c2, "\n";
     }
 }
 
@@ -54,15 +61,18 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 for my $c (@c) {
     if ($c =~ /^['\\]$/) {
         print SCRIPT "\$_ = '\\", $c, "'; print ord(\$_), \"\\n\";\n";
+        print WANT ord($c), "\n";
     }
     else {
         print SCRIPT "\$_ = '", $c, "'; print ord(\$_), \"\\n\";\n";
+        print WANT ord($c), "\n";
     }
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "\$_ = '", chr($c1), chr($c2), "'; print ord(\$_), \"\\n\";\n";
+        print WANT $c1 * 256 + $c2, "\n";
     }
 }
 
@@ -73,15 +83,18 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 for my $c (@c) {
     if ($c =~ /^['\\]$/) {
         print SCRIPT "\$_ = '\\", $c, "'; print ord \$_, 'A', 'B', 'C'; print \"\\n\";\n";
+        print WANT ord($c), 'A', 'B', 'C', "\n";
     }
     else {
         print SCRIPT "\$_ = '", $c, "'; print ord \$_, 'A', 'B', 'C'; print \"\\n\";\n";
+        print WANT ord($c), 'A', 'B', 'C', "\n";
     }
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "\$_ = '", chr($c1), chr($c2), "'; print ord \$_, 'A', 'B', 'C'; print \"\\n\";\n";
+        print WANT $c1 * 256 + $c2, 'A', 'B', 'C', "\n";
     }
 }
 
@@ -92,15 +105,18 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 for my $c (@c) {
     if ($c =~ /^['\\]$/) {
         print SCRIPT "print ord '\\", $c, "', \"\\n\";\n";
+        print WANT ord($c), "\n";
     }
     else {
         print SCRIPT "print ord '", $c, "', \"\\n\";\n";
+        print WANT ord($c), "\n";
     }
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "print ord '", chr($c1), chr($c2), "', \"\\n\";\n";
+        print WANT $c1 * 256 + $c2, "\n";
     }
 }
 
@@ -111,15 +127,18 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 for my $c (@c) {
     if ($c =~ /^['\\]$/) {
         print SCRIPT "print ord('\\", $c, "'), \"\\n\";\n";
+        print WANT ord($c), "\n";
     }
     else {
         print SCRIPT "print ord('", $c, "'), \"\\n\";\n";
+        print WANT ord($c), "\n";
     }
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "print ord('", chr($c1), chr($c2), "'), \"\\n\";\n";
+        print WANT $c1 * 256 + $c2, "\n";
     }
 }
 
@@ -130,18 +149,22 @@ for my $c1 (0x81..0x9F, 0xE0..0xFC) {
 for my $c (@c) {
     if ($c =~ /^['\\]$/) {
         print SCRIPT "print ord '\\", $c, "', 'A', 'B', 'C'; print \"\\n\";\n";
+        print WANT ord($c), 'A', 'B', 'C', "\n";
     }
     else {
         print SCRIPT "print ord '", $c, "', 'A', 'B', 'C'; print \"\\n\";\n";
+        print WANT ord($c), 'A', 'B', 'C', "\n";
     }
 }
 
 for my $c1 (0x81..0x9F, 0xE0..0xFC) {
     for my $c2 (0x40..0x7E, 0x80..0xFC) {
         print SCRIPT "print ord '", chr($c1), chr($c2), "', 'A', 'B', 'C'; print \"\\n\";\n";
+        print WANT $c1 * 256 + $c2, 'A', 'B', 'C', "\n";
     }
 }
 
 close(SCRIPT);
+close(WANT);
 
 #----------------------------------------------------------------------------
